CVS: jcontainer/loom/engine/src/java/org/jcontainer/loom/components/util/factory ComponentFactory.java,1.1,1.2 DefaultComponentFactory.java,1.2,1.3 ComponentBundle.java,1.2,NONE DefaultComponentBundle.java,1.2,NONE

Peter Donald <pdonald-yCVjj/[email protected]> Mon, 3 Nov 2003 00:18:00 -0600
Newsgroups gmane.comp.java.jcontainer.cvs
Message-ID <[email protected]>
Update of /cvsroot/jcontainer/jcontainer/loom/engine/src/java/org/jcontainer/loom/components/util/factory
In directory hogshead.codehaus.org:/tmp/cvs-serv21437/engine/src/java/org/jcontainer/loom/components/util/factory

Modified Files:
	ComponentFactory.java DefaultComponentFactory.java 
Removed Files:
	ComponentBundle.java DefaultComponentBundle.java 
Log Message:
Remove the ComponentBundle abstraction as it is no longer useful


Index: DefaultComponentFactory.java
===================================================================
RCS file: /cvsroot/jcontainer/jcontainer/loom/engine/src/java/org/jcontainer/loom/components/util/factory/DefaultComponentFactory.java,v
retrieving revision 1.2
retrieving revision 1.3
diff -u -d -r1.2 -r1.3
--- DefaultComponentFactory.java	3 Nov 2003 06:11:26 -0000	1.2
+++ DefaultComponentFactory.java	3 Nov 2003 06:17:58 -0000	1.3
@@ -56,15 +56,15 @@
      * Create a component by creating info for class
      * with specified name and loaded from factorys ClassLoader.
      *
-     * @see ComponentFactory#createBundle
+     * @see ComponentFactory#createInfo
      */
-    public ComponentBundle createBundle( final String implementationKey )
+    public ComponentInfo createInfo( final String implementationKey )
         throws Exception
     {
-        ComponentBundle bundle = (ComponentBundle)m_infos.get( implementationKey );
+        ComponentInfo bundle = (ComponentInfo)m_infos.get( implementationKey );
         if( null == bundle )
         {
-            bundle = newBundle( implementationKey );
+            bundle = createComponentInfo( implementationKey );
             m_infos.put( implementationKey, bundle );
         }
 
@@ -82,21 +82,6 @@
     {
         final Class clazz = getClassLoader().loadClass( implementationKey );
         return clazz.newInstance();
-    }
-
-    /**
-     * Create a bundle for specified key.
-     * Note that this does not cache bundle in any way.
-     *
-     * @param implementationKey the implementationKey
-     * @return the new ComponentBundle
-     * @throws Exception if unable to create bundle
-     */
-    protected ComponentBundle newBundle( final String implementationKey )
-        throws Exception
-    {
-        final ComponentInfo info = createComponentInfo( implementationKey );
-        return new DefaultComponentBundle( info );
     }
 
     /**

--- ComponentBundle.java DELETED ---

--- DefaultComponentBundle.java DELETED ---
Index: ComponentFactory.java
===================================================================
RCS file: /cvsroot/jcontainer/jcontainer/loom/engine/src/java/org/jcontainer/loom/components/util/factory/ComponentFactory.java,v
retrieving revision 1.1
retrieving revision 1.2
diff -u -d -r1.1 -r1.2
--- ComponentFactory.java	16 Oct 2003 14:45:46 -0000	1.1
+++ ComponentFactory.java	3 Nov 2003 06:17:58 -0000	1.2
@@ -7,11 +7,11 @@
  */
 package org.jcontainer.loom.components.util.factory;
 
-
+import org.jcontainer.loom.components.util.info.ComponentInfo;
 
 /**
  * This interface defines the mechanism via which a
- * component or its associated {@link org.jcontainer.loom.components.util.factory.ComponentBundle} can
+ * component or its associated ComponentInfo can
  * be created.
  *
  * <p>Usually the component or ComponentBundle will just be loaded
@@ -32,14 +32,13 @@
 public interface ComponentFactory
 {
     /**
-     * Create a {@link org.jcontainer.loom.components.util.factory.ComponentBundle} for component
-     * specified by implementationKey.
+     * Create a ComponentInfo for component specified by implementationKey.
      *
      * @param implementationKey the key indicating type of component (usually classname)
      * @return the ComponentBundle for component
      * @throws java.lang.Exception if unable to create Info object
      */
-    ComponentBundle createBundle( String implementationKey )
+    ComponentInfo createInfo( String implementationKey )
         throws Exception;
 
     /**
@@ -32,14 +32,13 @@
      *
      * @param implementationKey the key indicating type of component (usually classname)
-     * @return the ComponentBundle for component
-     * @throws java.lang.Exception if unable to create Info object
+     * @return the ComponentInfo for component
+     * @throws Exception if unable to create Info object
      */
